@@ -3,18 +3,21 @@ Main interface for route53 service type definitions.
 
 Usage::
 
-    from mypy_boto3.route53.type_defs import AlarmIdentifierTypeDef
+    ```python
+    from mypy_boto3_route53.type_defs import AccountLimitTypeDef
 
-    data: AlarmIdentifierTypeDef = {...}
+    data: AccountLimitTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,56 +25,59 @@ else:
 
 
 __all__ = (
+    "AccountLimitTypeDef",
     "AlarmIdentifierTypeDef",
-    "ChangeInfoTypeDef",
-    "AssociateVPCWithHostedZoneResponseTypeDef",
     "AliasTargetTypeDef",
-    "GeoLocationTypeDef",
-    "ResourceRecordTypeDef",
-    "ResourceRecordSetTypeDef",
+    "ChangeInfoTypeDef",
     "ChangeTypeDef",
+    "CloudWatchAlarmConfigurationTypeDef",
+    "DelegationSetTypeDef",
+    "DimensionTypeDef",
+    "GeoLocationDetailsTypeDef",
+    "GeoLocationTypeDef",
+    "HealthCheckConfigTypeDef",
+    "HealthCheckObservationTypeDef",
+    "HealthCheckTypeDef",
+    "HostedZoneConfigTypeDef",
+    "HostedZoneLimitTypeDef",
+    "HostedZoneTypeDef",
+    "LinkedServiceTypeDef",
+    "QueryLoggingConfigTypeDef",
+    "ResourceRecordSetTypeDef",
+    "ResourceRecordTypeDef",
+    "ResourceTagSetTypeDef",
+    "ReusableDelegationSetLimitTypeDef",
+    "StatusReportTypeDef",
+    "TagTypeDef",
+    "TrafficPolicyInstanceTypeDef",
+    "TrafficPolicySummaryTypeDef",
+    "TrafficPolicyTypeDef",
+    "VPCTypeDef",
+    "AssociateVPCWithHostedZoneResponseTypeDef",
     "ChangeBatchTypeDef",
     "ChangeResourceRecordSetsResponseTypeDef",
-    "DimensionTypeDef",
-    "CloudWatchAlarmConfigurationTypeDef",
-    "HealthCheckConfigTypeDef",
-    "LinkedServiceTypeDef",
-    "HealthCheckTypeDef",
     "CreateHealthCheckResponseTypeDef",
-    "DelegationSetTypeDef",
-    "HostedZoneConfigTypeDef",
-    "HostedZoneTypeDef",
-    "VPCTypeDef",
     "CreateHostedZoneResponseTypeDef",
-    "QueryLoggingConfigTypeDef",
     "CreateQueryLoggingConfigResponseTypeDef",
     "CreateReusableDelegationSetResponseTypeDef",
-    "TrafficPolicyInstanceTypeDef",
     "CreateTrafficPolicyInstanceResponseTypeDef",
-    "TrafficPolicyTypeDef",
     "CreateTrafficPolicyResponseTypeDef",
     "CreateTrafficPolicyVersionResponseTypeDef",
     "CreateVPCAssociationAuthorizationResponseTypeDef",
     "DeleteHostedZoneResponseTypeDef",
     "DisassociateVPCFromHostedZoneResponseTypeDef",
-    "AccountLimitTypeDef",
     "GetAccountLimitResponseTypeDef",
     "GetChangeResponseTypeDef",
     "GetCheckerIpRangesResponseTypeDef",
-    "GeoLocationDetailsTypeDef",
     "GetGeoLocationResponseTypeDef",
     "GetHealthCheckCountResponseTypeDef",
-    "StatusReportTypeDef",
-    "HealthCheckObservationTypeDef",
     "GetHealthCheckLastFailureReasonResponseTypeDef",
     "GetHealthCheckResponseTypeDef",
     "GetHealthCheckStatusResponseTypeDef",
     "GetHostedZoneCountResponseTypeDef",
-    "HostedZoneLimitTypeDef",
     "GetHostedZoneLimitResponseTypeDef",
     "GetHostedZoneResponseTypeDef",
     "GetQueryLoggingConfigResponseTypeDef",
-    "ReusableDelegationSetLimitTypeDef",
     "GetReusableDelegationSetLimitResponseTypeDef",
     "GetReusableDelegationSetResponseTypeDef",
     "GetTrafficPolicyInstanceCountResponseTypeDef",
@@ -84,11 +90,8 @@ __all__ = (
     "ListQueryLoggingConfigsResponseTypeDef",
     "ListResourceRecordSetsResponseTypeDef",
     "ListReusableDelegationSetsResponseTypeDef",
-    "TagTypeDef",
-    "ResourceTagSetTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListTagsForResourcesResponseTypeDef",
-    "TrafficPolicySummaryTypeDef",
     "ListTrafficPoliciesResponseTypeDef",
     "ListTrafficPolicyInstancesByHostedZoneResponseTypeDef",
     "ListTrafficPolicyInstancesByPolicyResponseTypeDef",
@@ -104,6 +107,20 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
+AccountLimitTypeDef = TypedDict(
+    "AccountLimitTypeDef",
+    {
+        "Type": Literal[
+            "MAX_HEALTH_CHECKS_BY_OWNER",
+            "MAX_HOSTED_ZONES_BY_OWNER",
+            "MAX_TRAFFIC_POLICY_INSTANCES_BY_OWNER",
+            "MAX_REUSABLE_DELEGATION_SETS_BY_OWNER",
+            "MAX_TRAFFIC_POLICIES_BY_OWNER",
+        ],
+        "Value": int,
+    },
+)
+
 AlarmIdentifierTypeDef = TypedDict(
     "AlarmIdentifierTypeDef",
     {
@@ -130,6 +147,7 @@ AlarmIdentifierTypeDef = TypedDict(
             "cn-northwest-1",
             "cn-north-1",
             "af-south-1",
+            "eu-south-1",
             "us-gov-west-1",
             "us-gov-east-1",
             "us-iso-east-1",
@@ -139,6 +157,10 @@ AlarmIdentifierTypeDef = TypedDict(
     },
 )
 
+AliasTargetTypeDef = TypedDict(
+    "AliasTargetTypeDef", {"HostedZoneId": str, "DNSName": str, "EvaluateTargetHealth": bool}
+)
+
 _RequiredChangeInfoTypeDef = TypedDict(
     "_RequiredChangeInfoTypeDef",
     {"Id": str, "Status": Literal["PENDING", "INSYNC"], "SubmittedAt": datetime},
@@ -150,105 +172,14 @@ class ChangeInfoTypeDef(_RequiredChangeInfoTypeDef, _OptionalChangeInfoTypeDef):
     pass
 
 
-AssociateVPCWithHostedZoneResponseTypeDef = TypedDict(
-    "AssociateVPCWithHostedZoneResponseTypeDef", {"ChangeInfo": ChangeInfoTypeDef}
-)
-
-AliasTargetTypeDef = TypedDict(
-    "AliasTargetTypeDef", {"HostedZoneId": str, "DNSName": str, "EvaluateTargetHealth": bool}
-)
-
-GeoLocationTypeDef = TypedDict(
-    "GeoLocationTypeDef",
-    {"ContinentCode": str, "CountryCode": str, "SubdivisionCode": str},
-    total=False,
-)
-
-ResourceRecordTypeDef = TypedDict("ResourceRecordTypeDef", {"Value": str})
-
-_RequiredResourceRecordSetTypeDef = TypedDict(
-    "_RequiredResourceRecordSetTypeDef",
-    {
-        "Name": str,
-        "Type": Literal[
-            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
-        ],
-    },
-)
-_OptionalResourceRecordSetTypeDef = TypedDict(
-    "_OptionalResourceRecordSetTypeDef",
-    {
-        "SetIdentifier": str,
-        "Weight": int,
-        "Region": Literal[
-            "us-east-1",
-            "us-east-2",
-            "us-west-1",
-            "us-west-2",
-            "ca-central-1",
-            "eu-west-1",
-            "eu-west-2",
-            "eu-west-3",
-            "eu-central-1",
-            "ap-southeast-1",
-            "ap-southeast-2",
-            "ap-northeast-1",
-            "ap-northeast-2",
-            "ap-northeast-3",
-            "eu-north-1",
-            "sa-east-1",
-            "cn-north-1",
-            "cn-northwest-1",
-            "ap-east-1",
-            "me-south-1",
-            "ap-south-1",
-            "af-south-1",
-        ],
-        "GeoLocation": GeoLocationTypeDef,
-        "Failover": Literal["PRIMARY", "SECONDARY"],
-        "MultiValueAnswer": bool,
-        "TTL": int,
-        "ResourceRecords": List[ResourceRecordTypeDef],
-        "AliasTarget": AliasTargetTypeDef,
-        "HealthCheckId": str,
-        "TrafficPolicyInstanceId": str,
-    },
-    total=False,
-)
-
-
-class ResourceRecordSetTypeDef(
-    _RequiredResourceRecordSetTypeDef, _OptionalResourceRecordSetTypeDef
-):
-    pass
-
-
 ChangeTypeDef = TypedDict(
     "ChangeTypeDef",
     {
         "Action": Literal["CREATE", "DELETE", "UPSERT"],
-        "ResourceRecordSet": ResourceRecordSetTypeDef,
+        "ResourceRecordSet": "ResourceRecordSetTypeDef",
     },
 )
 
-_RequiredChangeBatchTypeDef = TypedDict(
-    "_RequiredChangeBatchTypeDef", {"Changes": List[ChangeTypeDef]}
-)
-_OptionalChangeBatchTypeDef = TypedDict(
-    "_OptionalChangeBatchTypeDef", {"Comment": str}, total=False
-)
-
-
-class ChangeBatchTypeDef(_RequiredChangeBatchTypeDef, _OptionalChangeBatchTypeDef):
-    pass
-
-
-ChangeResourceRecordSetsResponseTypeDef = TypedDict(
-    "ChangeResourceRecordSetsResponseTypeDef", {"ChangeInfo": ChangeInfoTypeDef}
-)
-
-DimensionTypeDef = TypedDict("DimensionTypeDef", {"Name": str, "Value": str})
-
 _RequiredCloudWatchAlarmConfigurationTypeDef = TypedDict(
     "_RequiredCloudWatchAlarmConfigurationTypeDef",
     {
@@ -268,7 +199,7 @@ _RequiredCloudWatchAlarmConfigurationTypeDef = TypedDict(
 )
 _OptionalCloudWatchAlarmConfigurationTypeDef = TypedDict(
     "_OptionalCloudWatchAlarmConfigurationTypeDef",
-    {"Dimensions": List[DimensionTypeDef]},
+    {"Dimensions": List["DimensionTypeDef"]},
     total=False,
 )
 
@@ -279,6 +210,39 @@ class CloudWatchAlarmConfigurationTypeDef(
     pass
 
 
+_RequiredDelegationSetTypeDef = TypedDict(
+    "_RequiredDelegationSetTypeDef", {"NameServers": List[str]}
+)
+_OptionalDelegationSetTypeDef = TypedDict(
+    "_OptionalDelegationSetTypeDef", {"Id": str, "CallerReference": str}, total=False
+)
+
+
+class DelegationSetTypeDef(_RequiredDelegationSetTypeDef, _OptionalDelegationSetTypeDef):
+    pass
+
+
+DimensionTypeDef = TypedDict("DimensionTypeDef", {"Name": str, "Value": str})
+
+GeoLocationDetailsTypeDef = TypedDict(
+    "GeoLocationDetailsTypeDef",
+    {
+        "ContinentCode": str,
+        "ContinentName": str,
+        "CountryCode": str,
+        "CountryName": str,
+        "SubdivisionCode": str,
+        "SubdivisionName": str,
+    },
+    total=False,
+)
+
+GeoLocationTypeDef = TypedDict(
+    "GeoLocationTypeDef",
+    {"ContinentCode": str, "CountryCode": str, "SubdivisionCode": str},
+    total=False,
+)
+
 _RequiredHealthCheckConfigTypeDef = TypedDict(
     "_RequiredHealthCheckConfigTypeDef",
     {
@@ -321,7 +285,7 @@ _OptionalHealthCheckConfigTypeDef = TypedDict(
                 "sa-east-1",
             ]
         ],
-        "AlarmIdentifier": AlarmIdentifierTypeDef,
+        "AlarmIdentifier": "AlarmIdentifierTypeDef",
         "InsufficientDataHealthStatus": Literal["Healthy", "Unhealthy", "LastKnownStatus"],
     },
     total=False,
@@ -334,8 +298,23 @@ class HealthCheckConfigTypeDef(
     pass
 
 
-LinkedServiceTypeDef = TypedDict(
-    "LinkedServiceTypeDef", {"ServicePrincipal": str, "Description": str}, total=False
+HealthCheckObservationTypeDef = TypedDict(
+    "HealthCheckObservationTypeDef",
+    {
+        "Region": Literal[
+            "us-east-1",
+            "us-west-1",
+            "us-west-2",
+            "eu-west-1",
+            "ap-southeast-1",
+            "ap-southeast-2",
+            "ap-northeast-1",
+            "sa-east-1",
+        ],
+        "IPAddress": str,
+        "StatusReport": "StatusReportTypeDef",
+    },
+    total=False,
 )
 
 _RequiredHealthCheckTypeDef = TypedDict(
@@ -343,15 +322,15 @@ _RequiredHealthCheckTypeDef = TypedDict(
     {
         "Id": str,
         "CallerReference": str,
-        "HealthCheckConfig": HealthCheckConfigTypeDef,
+        "HealthCheckConfig": "HealthCheckConfigTypeDef",
         "HealthCheckVersion": int,
     },
 )
 _OptionalHealthCheckTypeDef = TypedDict(
     "_OptionalHealthCheckTypeDef",
     {
-        "LinkedService": LinkedServiceTypeDef,
-        "CloudWatchAlarmConfiguration": CloudWatchAlarmConfigurationTypeDef,
+        "LinkedService": "LinkedServiceTypeDef",
+        "CloudWatchAlarmConfiguration": "CloudWatchAlarmConfigurationTypeDef",
     },
     total=False,
 )
@@ -361,35 +340,24 @@ class HealthCheckTypeDef(_RequiredHealthCheckTypeDef, _OptionalHealthCheckTypeDe
     pass
 
 
-CreateHealthCheckResponseTypeDef = TypedDict(
-    "CreateHealthCheckResponseTypeDef", {"HealthCheck": HealthCheckTypeDef, "Location": str}
-)
-
-_RequiredDelegationSetTypeDef = TypedDict(
-    "_RequiredDelegationSetTypeDef", {"NameServers": List[str]}
-)
-_OptionalDelegationSetTypeDef = TypedDict(
-    "_OptionalDelegationSetTypeDef", {"Id": str, "CallerReference": str}, total=False
-)
-
-
-class DelegationSetTypeDef(_RequiredDelegationSetTypeDef, _OptionalDelegationSetTypeDef):
-    pass
-
-
 HostedZoneConfigTypeDef = TypedDict(
     "HostedZoneConfigTypeDef", {"Comment": str, "PrivateZone": bool}, total=False
 )
 
+HostedZoneLimitTypeDef = TypedDict(
+    "HostedZoneLimitTypeDef",
+    {"Type": Literal["MAX_RRSETS_BY_ZONE", "MAX_VPCS_ASSOCIATED_BY_ZONE"], "Value": int},
+)
+
 _RequiredHostedZoneTypeDef = TypedDict(
     "_RequiredHostedZoneTypeDef", {"Id": str, "Name": str, "CallerReference": str}
 )
 _OptionalHostedZoneTypeDef = TypedDict(
     "_OptionalHostedZoneTypeDef",
     {
-        "Config": HostedZoneConfigTypeDef,
+        "Config": "HostedZoneConfigTypeDef",
         "ResourceRecordSetCount": int,
-        "LinkedService": LinkedServiceTypeDef,
+        "LinkedService": "LinkedServiceTypeDef",
     },
     total=False,
 )
@@ -399,6 +367,146 @@ class HostedZoneTypeDef(_RequiredHostedZoneTypeDef, _OptionalHostedZoneTypeDef):
     pass
 
 
+LinkedServiceTypeDef = TypedDict(
+    "LinkedServiceTypeDef", {"ServicePrincipal": str, "Description": str}, total=False
+)
+
+QueryLoggingConfigTypeDef = TypedDict(
+    "QueryLoggingConfigTypeDef", {"Id": str, "HostedZoneId": str, "CloudWatchLogsLogGroupArn": str}
+)
+
+_RequiredResourceRecordSetTypeDef = TypedDict(
+    "_RequiredResourceRecordSetTypeDef",
+    {
+        "Name": str,
+        "Type": Literal[
+            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
+        ],
+    },
+)
+_OptionalResourceRecordSetTypeDef = TypedDict(
+    "_OptionalResourceRecordSetTypeDef",
+    {
+        "SetIdentifier": str,
+        "Weight": int,
+        "Region": Literal[
+            "us-east-1",
+            "us-east-2",
+            "us-west-1",
+            "us-west-2",
+            "ca-central-1",
+            "eu-west-1",
+            "eu-west-2",
+            "eu-west-3",
+            "eu-central-1",
+            "ap-southeast-1",
+            "ap-southeast-2",
+            "ap-northeast-1",
+            "ap-northeast-2",
+            "ap-northeast-3",
+            "eu-north-1",
+            "sa-east-1",
+            "cn-north-1",
+            "cn-northwest-1",
+            "ap-east-1",
+            "me-south-1",
+            "ap-south-1",
+            "af-south-1",
+            "eu-south-1",
+        ],
+        "GeoLocation": "GeoLocationTypeDef",
+        "Failover": Literal["PRIMARY", "SECONDARY"],
+        "MultiValueAnswer": bool,
+        "TTL": int,
+        "ResourceRecords": List["ResourceRecordTypeDef"],
+        "AliasTarget": "AliasTargetTypeDef",
+        "HealthCheckId": str,
+        "TrafficPolicyInstanceId": str,
+    },
+    total=False,
+)
+
+
+class ResourceRecordSetTypeDef(
+    _RequiredResourceRecordSetTypeDef, _OptionalResourceRecordSetTypeDef
+):
+    pass
+
+
+ResourceRecordTypeDef = TypedDict("ResourceRecordTypeDef", {"Value": str})
+
+ResourceTagSetTypeDef = TypedDict(
+    "ResourceTagSetTypeDef",
+    {
+        "ResourceType": Literal["healthcheck", "hostedzone"],
+        "ResourceId": str,
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+ReusableDelegationSetLimitTypeDef = TypedDict(
+    "ReusableDelegationSetLimitTypeDef",
+    {"Type": Literal["MAX_ZONES_BY_REUSABLE_DELEGATION_SET"], "Value": int},
+)
+
+StatusReportTypeDef = TypedDict(
+    "StatusReportTypeDef", {"Status": str, "CheckedTime": datetime}, total=False
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
+TrafficPolicyInstanceTypeDef = TypedDict(
+    "TrafficPolicyInstanceTypeDef",
+    {
+        "Id": str,
+        "HostedZoneId": str,
+        "Name": str,
+        "TTL": int,
+        "State": str,
+        "Message": str,
+        "TrafficPolicyId": str,
+        "TrafficPolicyVersion": int,
+        "TrafficPolicyType": Literal[
+            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
+        ],
+    },
+)
+
+TrafficPolicySummaryTypeDef = TypedDict(
+    "TrafficPolicySummaryTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Type": Literal[
+            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
+        ],
+        "LatestVersion": int,
+        "TrafficPolicyCount": int,
+    },
+)
+
+_RequiredTrafficPolicyTypeDef = TypedDict(
+    "_RequiredTrafficPolicyTypeDef",
+    {
+        "Id": str,
+        "Version": int,
+        "Name": str,
+        "Type": Literal[
+            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
+        ],
+        "Document": str,
+    },
+)
+_OptionalTrafficPolicyTypeDef = TypedDict(
+    "_OptionalTrafficPolicyTypeDef", {"Comment": str}, total=False
+)
+
+
+class TrafficPolicyTypeDef(_RequiredTrafficPolicyTypeDef, _OptionalTrafficPolicyTypeDef):
+    pass
+
+
 VPCTypeDef = TypedDict(
     "VPCTypeDef",
     {
@@ -428,23 +536,48 @@ VPCTypeDef = TypedDict(
             "ca-central-1",
             "cn-north-1",
             "af-south-1",
+            "eu-south-1",
         ],
         "VPCId": str,
     },
     total=False,
 )
 
+AssociateVPCWithHostedZoneResponseTypeDef = TypedDict(
+    "AssociateVPCWithHostedZoneResponseTypeDef", {"ChangeInfo": "ChangeInfoTypeDef"}
+)
+
+_RequiredChangeBatchTypeDef = TypedDict(
+    "_RequiredChangeBatchTypeDef", {"Changes": List["ChangeTypeDef"]}
+)
+_OptionalChangeBatchTypeDef = TypedDict(
+    "_OptionalChangeBatchTypeDef", {"Comment": str}, total=False
+)
+
+
+class ChangeBatchTypeDef(_RequiredChangeBatchTypeDef, _OptionalChangeBatchTypeDef):
+    pass
+
+
+ChangeResourceRecordSetsResponseTypeDef = TypedDict(
+    "ChangeResourceRecordSetsResponseTypeDef", {"ChangeInfo": "ChangeInfoTypeDef"}
+)
+
+CreateHealthCheckResponseTypeDef = TypedDict(
+    "CreateHealthCheckResponseTypeDef", {"HealthCheck": "HealthCheckTypeDef", "Location": str}
+)
+
 _RequiredCreateHostedZoneResponseTypeDef = TypedDict(
     "_RequiredCreateHostedZoneResponseTypeDef",
     {
-        "HostedZone": HostedZoneTypeDef,
-        "ChangeInfo": ChangeInfoTypeDef,
-        "DelegationSet": DelegationSetTypeDef,
+        "HostedZone": "HostedZoneTypeDef",
+        "ChangeInfo": "ChangeInfoTypeDef",
+        "DelegationSet": "DelegationSetTypeDef",
         "Location": str,
     },
 )
 _OptionalCreateHostedZoneResponseTypeDef = TypedDict(
-    "_OptionalCreateHostedZoneResponseTypeDef", {"VPC": VPCTypeDef}, total=False
+    "_OptionalCreateHostedZoneResponseTypeDef", {"VPC": "VPCTypeDef"}, total=False
 )
 
 
@@ -454,185 +587,90 @@ class CreateHostedZoneResponseTypeDef(
     pass
 
 
-QueryLoggingConfigTypeDef = TypedDict(
-    "QueryLoggingConfigTypeDef", {"Id": str, "HostedZoneId": str, "CloudWatchLogsLogGroupArn": str}
-)
-
 CreateQueryLoggingConfigResponseTypeDef = TypedDict(
     "CreateQueryLoggingConfigResponseTypeDef",
-    {"QueryLoggingConfig": QueryLoggingConfigTypeDef, "Location": str},
+    {"QueryLoggingConfig": "QueryLoggingConfigTypeDef", "Location": str},
 )
 
 CreateReusableDelegationSetResponseTypeDef = TypedDict(
     "CreateReusableDelegationSetResponseTypeDef",
-    {"DelegationSet": DelegationSetTypeDef, "Location": str},
-)
-
-TrafficPolicyInstanceTypeDef = TypedDict(
-    "TrafficPolicyInstanceTypeDef",
-    {
-        "Id": str,
-        "HostedZoneId": str,
-        "Name": str,
-        "TTL": int,
-        "State": str,
-        "Message": str,
-        "TrafficPolicyId": str,
-        "TrafficPolicyVersion": int,
-        "TrafficPolicyType": Literal[
-            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
-        ],
-    },
+    {"DelegationSet": "DelegationSetTypeDef", "Location": str},
 )
 
 CreateTrafficPolicyInstanceResponseTypeDef = TypedDict(
     "CreateTrafficPolicyInstanceResponseTypeDef",
-    {"TrafficPolicyInstance": TrafficPolicyInstanceTypeDef, "Location": str},
+    {"TrafficPolicyInstance": "TrafficPolicyInstanceTypeDef", "Location": str},
 )
 
-_RequiredTrafficPolicyTypeDef = TypedDict(
-    "_RequiredTrafficPolicyTypeDef",
-    {
-        "Id": str,
-        "Version": int,
-        "Name": str,
-        "Type": Literal[
-            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
-        ],
-        "Document": str,
-    },
-)
-_OptionalTrafficPolicyTypeDef = TypedDict(
-    "_OptionalTrafficPolicyTypeDef", {"Comment": str}, total=False
-)
-
-
-class TrafficPolicyTypeDef(_RequiredTrafficPolicyTypeDef, _OptionalTrafficPolicyTypeDef):
-    pass
-
-
 CreateTrafficPolicyResponseTypeDef = TypedDict(
-    "CreateTrafficPolicyResponseTypeDef", {"TrafficPolicy": TrafficPolicyTypeDef, "Location": str}
+    "CreateTrafficPolicyResponseTypeDef", {"TrafficPolicy": "TrafficPolicyTypeDef", "Location": str}
 )
 
 CreateTrafficPolicyVersionResponseTypeDef = TypedDict(
     "CreateTrafficPolicyVersionResponseTypeDef",
-    {"TrafficPolicy": TrafficPolicyTypeDef, "Location": str},
+    {"TrafficPolicy": "TrafficPolicyTypeDef", "Location": str},
 )
 
 CreateVPCAssociationAuthorizationResponseTypeDef = TypedDict(
-    "CreateVPCAssociationAuthorizationResponseTypeDef", {"HostedZoneId": str, "VPC": VPCTypeDef}
+    "CreateVPCAssociationAuthorizationResponseTypeDef", {"HostedZoneId": str, "VPC": "VPCTypeDef"}
 )
 
 DeleteHostedZoneResponseTypeDef = TypedDict(
-    "DeleteHostedZoneResponseTypeDef", {"ChangeInfo": ChangeInfoTypeDef}
+    "DeleteHostedZoneResponseTypeDef", {"ChangeInfo": "ChangeInfoTypeDef"}
 )
 
 DisassociateVPCFromHostedZoneResponseTypeDef = TypedDict(
-    "DisassociateVPCFromHostedZoneResponseTypeDef", {"ChangeInfo": ChangeInfoTypeDef}
-)
-
-AccountLimitTypeDef = TypedDict(
-    "AccountLimitTypeDef",
-    {
-        "Type": Literal[
-            "MAX_HEALTH_CHECKS_BY_OWNER",
-            "MAX_HOSTED_ZONES_BY_OWNER",
-            "MAX_TRAFFIC_POLICY_INSTANCES_BY_OWNER",
-            "MAX_REUSABLE_DELEGATION_SETS_BY_OWNER",
-            "MAX_TRAFFIC_POLICIES_BY_OWNER",
-        ],
-        "Value": int,
-    },
+    "DisassociateVPCFromHostedZoneResponseTypeDef", {"ChangeInfo": "ChangeInfoTypeDef"}
 )
 
 GetAccountLimitResponseTypeDef = TypedDict(
-    "GetAccountLimitResponseTypeDef", {"Limit": AccountLimitTypeDef, "Count": int}
+    "GetAccountLimitResponseTypeDef", {"Limit": "AccountLimitTypeDef", "Count": int}
 )
 
-GetChangeResponseTypeDef = TypedDict("GetChangeResponseTypeDef", {"ChangeInfo": ChangeInfoTypeDef})
+GetChangeResponseTypeDef = TypedDict(
+    "GetChangeResponseTypeDef", {"ChangeInfo": "ChangeInfoTypeDef"}
+)
 
 GetCheckerIpRangesResponseTypeDef = TypedDict(
     "GetCheckerIpRangesResponseTypeDef", {"CheckerIpRanges": List[str]}
 )
 
-GeoLocationDetailsTypeDef = TypedDict(
-    "GeoLocationDetailsTypeDef",
-    {
-        "ContinentCode": str,
-        "ContinentName": str,
-        "CountryCode": str,
-        "CountryName": str,
-        "SubdivisionCode": str,
-        "SubdivisionName": str,
-    },
-    total=False,
-)
-
 GetGeoLocationResponseTypeDef = TypedDict(
-    "GetGeoLocationResponseTypeDef", {"GeoLocationDetails": GeoLocationDetailsTypeDef}
+    "GetGeoLocationResponseTypeDef", {"GeoLocationDetails": "GeoLocationDetailsTypeDef"}
 )
 
 GetHealthCheckCountResponseTypeDef = TypedDict(
     "GetHealthCheckCountResponseTypeDef", {"HealthCheckCount": int}
 )
 
-StatusReportTypeDef = TypedDict(
-    "StatusReportTypeDef", {"Status": str, "CheckedTime": datetime}, total=False
-)
-
-HealthCheckObservationTypeDef = TypedDict(
-    "HealthCheckObservationTypeDef",
-    {
-        "Region": Literal[
-            "us-east-1",
-            "us-west-1",
-            "us-west-2",
-            "eu-west-1",
-            "ap-southeast-1",
-            "ap-southeast-2",
-            "ap-northeast-1",
-            "sa-east-1",
-        ],
-        "IPAddress": str,
-        "StatusReport": StatusReportTypeDef,
-    },
-    total=False,
-)
-
 GetHealthCheckLastFailureReasonResponseTypeDef = TypedDict(
     "GetHealthCheckLastFailureReasonResponseTypeDef",
-    {"HealthCheckObservations": List[HealthCheckObservationTypeDef]},
+    {"HealthCheckObservations": List["HealthCheckObservationTypeDef"]},
 )
 
 GetHealthCheckResponseTypeDef = TypedDict(
-    "GetHealthCheckResponseTypeDef", {"HealthCheck": HealthCheckTypeDef}
+    "GetHealthCheckResponseTypeDef", {"HealthCheck": "HealthCheckTypeDef"}
 )
 
 GetHealthCheckStatusResponseTypeDef = TypedDict(
     "GetHealthCheckStatusResponseTypeDef",
-    {"HealthCheckObservations": List[HealthCheckObservationTypeDef]},
+    {"HealthCheckObservations": List["HealthCheckObservationTypeDef"]},
 )
 
 GetHostedZoneCountResponseTypeDef = TypedDict(
     "GetHostedZoneCountResponseTypeDef", {"HostedZoneCount": int}
 )
 
-HostedZoneLimitTypeDef = TypedDict(
-    "HostedZoneLimitTypeDef",
-    {"Type": Literal["MAX_RRSETS_BY_ZONE", "MAX_VPCS_ASSOCIATED_BY_ZONE"], "Value": int},
-)
-
 GetHostedZoneLimitResponseTypeDef = TypedDict(
-    "GetHostedZoneLimitResponseTypeDef", {"Limit": HostedZoneLimitTypeDef, "Count": int}
+    "GetHostedZoneLimitResponseTypeDef", {"Limit": "HostedZoneLimitTypeDef", "Count": int}
 )
 
 _RequiredGetHostedZoneResponseTypeDef = TypedDict(
-    "_RequiredGetHostedZoneResponseTypeDef", {"HostedZone": HostedZoneTypeDef}
+    "_RequiredGetHostedZoneResponseTypeDef", {"HostedZone": "HostedZoneTypeDef"}
 )
 _OptionalGetHostedZoneResponseTypeDef = TypedDict(
     "_OptionalGetHostedZoneResponseTypeDef",
-    {"DelegationSet": DelegationSetTypeDef, "VPCs": List[VPCTypeDef]},
+    {"DelegationSet": "DelegationSetTypeDef", "VPCs": List["VPCTypeDef"]},
     total=False,
 )
 
@@ -644,21 +682,16 @@ class GetHostedZoneResponseTypeDef(
 
 
 GetQueryLoggingConfigResponseTypeDef = TypedDict(
-    "GetQueryLoggingConfigResponseTypeDef", {"QueryLoggingConfig": QueryLoggingConfigTypeDef}
-)
-
-ReusableDelegationSetLimitTypeDef = TypedDict(
-    "ReusableDelegationSetLimitTypeDef",
-    {"Type": Literal["MAX_ZONES_BY_REUSABLE_DELEGATION_SET"], "Value": int},
+    "GetQueryLoggingConfigResponseTypeDef", {"QueryLoggingConfig": "QueryLoggingConfigTypeDef"}
 )
 
 GetReusableDelegationSetLimitResponseTypeDef = TypedDict(
     "GetReusableDelegationSetLimitResponseTypeDef",
-    {"Limit": ReusableDelegationSetLimitTypeDef, "Count": int},
+    {"Limit": "ReusableDelegationSetLimitTypeDef", "Count": int},
 )
 
 GetReusableDelegationSetResponseTypeDef = TypedDict(
-    "GetReusableDelegationSetResponseTypeDef", {"DelegationSet": DelegationSetTypeDef}
+    "GetReusableDelegationSetResponseTypeDef", {"DelegationSet": "DelegationSetTypeDef"}
 )
 
 GetTrafficPolicyInstanceCountResponseTypeDef = TypedDict(
@@ -667,17 +700,17 @@ GetTrafficPolicyInstanceCountResponseTypeDef = TypedDict(
 
 GetTrafficPolicyInstanceResponseTypeDef = TypedDict(
     "GetTrafficPolicyInstanceResponseTypeDef",
-    {"TrafficPolicyInstance": TrafficPolicyInstanceTypeDef},
+    {"TrafficPolicyInstance": "TrafficPolicyInstanceTypeDef"},
 )
 
 GetTrafficPolicyResponseTypeDef = TypedDict(
-    "GetTrafficPolicyResponseTypeDef", {"TrafficPolicy": TrafficPolicyTypeDef}
+    "GetTrafficPolicyResponseTypeDef", {"TrafficPolicy": "TrafficPolicyTypeDef"}
 )
 
 _RequiredListGeoLocationsResponseTypeDef = TypedDict(
     "_RequiredListGeoLocationsResponseTypeDef",
     {
-        "GeoLocationDetailsList": List[GeoLocationDetailsTypeDef],
+        "GeoLocationDetailsList": List["GeoLocationDetailsTypeDef"],
         "IsTruncated": bool,
         "MaxItems": str,
     },
@@ -697,7 +730,12 @@ class ListGeoLocationsResponseTypeDef(
 
 _RequiredListHealthChecksResponseTypeDef = TypedDict(
     "_RequiredListHealthChecksResponseTypeDef",
-    {"HealthChecks": List[HealthCheckTypeDef], "Marker": str, "IsTruncated": bool, "MaxItems": str},
+    {
+        "HealthChecks": List["HealthCheckTypeDef"],
+        "Marker": str,
+        "IsTruncated": bool,
+        "MaxItems": str,
+    },
 )
 _OptionalListHealthChecksResponseTypeDef = TypedDict(
     "_OptionalListHealthChecksResponseTypeDef", {"NextMarker": str}, total=False
@@ -712,7 +750,7 @@ class ListHealthChecksResponseTypeDef(
 
 _RequiredListHostedZonesByNameResponseTypeDef = TypedDict(
     "_RequiredListHostedZonesByNameResponseTypeDef",
-    {"HostedZones": List[HostedZoneTypeDef], "IsTruncated": bool, "MaxItems": str},
+    {"HostedZones": List["HostedZoneTypeDef"], "IsTruncated": bool, "MaxItems": str},
 )
 _OptionalListHostedZonesByNameResponseTypeDef = TypedDict(
     "_OptionalListHostedZonesByNameResponseTypeDef",
@@ -729,7 +767,7 @@ class ListHostedZonesByNameResponseTypeDef(
 
 _RequiredListHostedZonesResponseTypeDef = TypedDict(
     "_RequiredListHostedZonesResponseTypeDef",
-    {"HostedZones": List[HostedZoneTypeDef], "Marker": str, "IsTruncated": bool, "MaxItems": str},
+    {"HostedZones": List["HostedZoneTypeDef"], "Marker": str, "IsTruncated": bool, "MaxItems": str},
 )
 _OptionalListHostedZonesResponseTypeDef = TypedDict(
     "_OptionalListHostedZonesResponseTypeDef", {"NextMarker": str}, total=False
@@ -744,7 +782,7 @@ class ListHostedZonesResponseTypeDef(
 
 _RequiredListQueryLoggingConfigsResponseTypeDef = TypedDict(
     "_RequiredListQueryLoggingConfigsResponseTypeDef",
-    {"QueryLoggingConfigs": List[QueryLoggingConfigTypeDef]},
+    {"QueryLoggingConfigs": List["QueryLoggingConfigTypeDef"]},
 )
 _OptionalListQueryLoggingConfigsResponseTypeDef = TypedDict(
     "_OptionalListQueryLoggingConfigsResponseTypeDef", {"NextToken": str}, total=False
@@ -759,7 +797,7 @@ class ListQueryLoggingConfigsResponseTypeDef(
 
 _RequiredListResourceRecordSetsResponseTypeDef = TypedDict(
     "_RequiredListResourceRecordSetsResponseTypeDef",
-    {"ResourceRecordSets": List[ResourceRecordSetTypeDef], "IsTruncated": bool, "MaxItems": str},
+    {"ResourceRecordSets": List["ResourceRecordSetTypeDef"], "IsTruncated": bool, "MaxItems": str},
 )
 _OptionalListResourceRecordSetsResponseTypeDef = TypedDict(
     "_OptionalListResourceRecordSetsResponseTypeDef",
@@ -783,7 +821,7 @@ class ListResourceRecordSetsResponseTypeDef(
 _RequiredListReusableDelegationSetsResponseTypeDef = TypedDict(
     "_RequiredListReusableDelegationSetsResponseTypeDef",
     {
-        "DelegationSets": List[DelegationSetTypeDef],
+        "DelegationSets": List["DelegationSetTypeDef"],
         "Marker": str,
         "IsTruncated": bool,
         "MaxItems": str,
@@ -801,43 +839,18 @@ class ListReusableDelegationSetsResponseTypeDef(
     pass
 
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
-
-ResourceTagSetTypeDef = TypedDict(
-    "ResourceTagSetTypeDef",
-    {
-        "ResourceType": Literal["healthcheck", "hostedzone"],
-        "ResourceId": str,
-        "Tags": List[TagTypeDef],
-    },
-    total=False,
-)
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"ResourceTagSet": ResourceTagSetTypeDef}
+    "ListTagsForResourceResponseTypeDef", {"ResourceTagSet": "ResourceTagSetTypeDef"}
 )
 
 ListTagsForResourcesResponseTypeDef = TypedDict(
-    "ListTagsForResourcesResponseTypeDef", {"ResourceTagSets": List[ResourceTagSetTypeDef]}
-)
-
-TrafficPolicySummaryTypeDef = TypedDict(
-    "TrafficPolicySummaryTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Type": Literal[
-            "SOA", "A", "TXT", "NS", "CNAME", "MX", "NAPTR", "PTR", "SRV", "SPF", "AAAA", "CAA"
-        ],
-        "LatestVersion": int,
-        "TrafficPolicyCount": int,
-    },
+    "ListTagsForResourcesResponseTypeDef", {"ResourceTagSets": List["ResourceTagSetTypeDef"]}
 )
 
 ListTrafficPoliciesResponseTypeDef = TypedDict(
     "ListTrafficPoliciesResponseTypeDef",
     {
-        "TrafficPolicySummaries": List[TrafficPolicySummaryTypeDef],
+        "TrafficPolicySummaries": List["TrafficPolicySummaryTypeDef"],
         "IsTruncated": bool,
         "TrafficPolicyIdMarker": str,
         "MaxItems": str,
@@ -847,7 +860,7 @@ ListTrafficPoliciesResponseTypeDef = TypedDict(
 _RequiredListTrafficPolicyInstancesByHostedZoneResponseTypeDef = TypedDict(
     "_RequiredListTrafficPolicyInstancesByHostedZoneResponseTypeDef",
     {
-        "TrafficPolicyInstances": List[TrafficPolicyInstanceTypeDef],
+        "TrafficPolicyInstances": List["TrafficPolicyInstanceTypeDef"],
         "IsTruncated": bool,
         "MaxItems": str,
     },
@@ -874,7 +887,7 @@ class ListTrafficPolicyInstancesByHostedZoneResponseTypeDef(
 _RequiredListTrafficPolicyInstancesByPolicyResponseTypeDef = TypedDict(
     "_RequiredListTrafficPolicyInstancesByPolicyResponseTypeDef",
     {
-        "TrafficPolicyInstances": List[TrafficPolicyInstanceTypeDef],
+        "TrafficPolicyInstances": List["TrafficPolicyInstanceTypeDef"],
         "IsTruncated": bool,
         "MaxItems": str,
     },
@@ -902,7 +915,7 @@ class ListTrafficPolicyInstancesByPolicyResponseTypeDef(
 _RequiredListTrafficPolicyInstancesResponseTypeDef = TypedDict(
     "_RequiredListTrafficPolicyInstancesResponseTypeDef",
     {
-        "TrafficPolicyInstances": List[TrafficPolicyInstanceTypeDef],
+        "TrafficPolicyInstances": List["TrafficPolicyInstanceTypeDef"],
         "IsTruncated": bool,
         "MaxItems": str,
     },
@@ -930,7 +943,7 @@ class ListTrafficPolicyInstancesResponseTypeDef(
 ListTrafficPolicyVersionsResponseTypeDef = TypedDict(
     "ListTrafficPolicyVersionsResponseTypeDef",
     {
-        "TrafficPolicies": List[TrafficPolicyTypeDef],
+        "TrafficPolicies": List["TrafficPolicyTypeDef"],
         "IsTruncated": bool,
         "TrafficPolicyVersionMarker": str,
         "MaxItems": str,
@@ -939,7 +952,7 @@ ListTrafficPolicyVersionsResponseTypeDef = TypedDict(
 
 _RequiredListVPCAssociationAuthorizationsResponseTypeDef = TypedDict(
     "_RequiredListVPCAssociationAuthorizationsResponseTypeDef",
-    {"HostedZoneId": str, "VPCs": List[VPCTypeDef]},
+    {"HostedZoneId": str, "VPCs": List["VPCTypeDef"]},
 )
 _OptionalListVPCAssociationAuthorizationsResponseTypeDef = TypedDict(
     "_OptionalListVPCAssociationAuthorizationsResponseTypeDef", {"NextToken": str}, total=False
@@ -972,20 +985,20 @@ TestDNSAnswerResponseTypeDef = TypedDict(
 )
 
 UpdateHealthCheckResponseTypeDef = TypedDict(
-    "UpdateHealthCheckResponseTypeDef", {"HealthCheck": HealthCheckTypeDef}
+    "UpdateHealthCheckResponseTypeDef", {"HealthCheck": "HealthCheckTypeDef"}
 )
 
 UpdateHostedZoneCommentResponseTypeDef = TypedDict(
-    "UpdateHostedZoneCommentResponseTypeDef", {"HostedZone": HostedZoneTypeDef}
+    "UpdateHostedZoneCommentResponseTypeDef", {"HostedZone": "HostedZoneTypeDef"}
 )
 
 UpdateTrafficPolicyCommentResponseTypeDef = TypedDict(
-    "UpdateTrafficPolicyCommentResponseTypeDef", {"TrafficPolicy": TrafficPolicyTypeDef}
+    "UpdateTrafficPolicyCommentResponseTypeDef", {"TrafficPolicy": "TrafficPolicyTypeDef"}
 )
 
 UpdateTrafficPolicyInstanceResponseTypeDef = TypedDict(
     "UpdateTrafficPolicyInstanceResponseTypeDef",
-    {"TrafficPolicyInstance": TrafficPolicyInstanceTypeDef},
+    {"TrafficPolicyInstance": "TrafficPolicyInstanceTypeDef"},
 )
 
 WaiterConfigTypeDef = TypedDict(
